@@ -19,6 +19,16 @@ from .const import (
     STATE_WARM_WHITE,
 )
 from .protocol import (
+    A1_NUM_TO_OPERATING_MODE,
+    A1_NUM_TO_PROTOCOL,
+    A1_OPERATING_MODE_TO_NUM,
+    A1_PROTOCOL_TO_NUM,
+    ADDRESSABLE_RGB_NUM_TO_WIRING,
+    ADDRESSABLE_RGB_WIRING_TO_NUM,
+    NEW_ADDRESSABLE_NUM_TO_OPERATING_MODE,
+    NEW_ADDRESSABLE_NUM_TO_PROTOCOL,
+    NEW_ADDRESSABLE_OPERATING_MODE_TO_NUM,
+    NEW_ADDRESSABLE_PROTOCOL_TO_NUM,
     PROTOCOL_LEDENET_8BYTE,
     PROTOCOL_LEDENET_8BYTE_AUTO_ON,
     PROTOCOL_LEDENET_8BYTE_DIMMABLE_EFFECTS,
@@ -31,6 +41,17 @@ from .protocol import (
     PROTOCOL_LEDENET_ADDRESSABLE_CHRISTMAS,
     PROTOCOL_LEDENET_CCT,
     PROTOCOL_LEDENET_ORIGINAL,
+    PROTOCOL_LEDENET_ORIGINAL_CCT,
+    RGB_NUM_TO_WIRING,
+    RGB_WIRING_TO_NUM,
+    RGBW_MODE_TO_NUM,
+    RGBW_NUM_TO_MODE,
+    RGBW_NUM_TO_WIRING,
+    RGBW_WIRING_TO_NUM,
+    RGBWW_MODE_TO_NUM,
+    RGBWW_NUM_TO_MODE,
+    RGBWW_NUM_TO_WIRING,
+    RGBWW_WIRING_TO_NUM,
 )
 
 # BL likely means BL602 chips
@@ -65,33 +86,6 @@ class MinVersionProtocol:
     protocol: str
 
 
-@dataclass
-class LEDENETModel:
-    model_num: int  # The model number aka byte 1
-    models: List[str]  # The model names from discovery
-    description: str  # Description of the model ({type} {color_mode})
-    always_writes_white_and_colors: bool  # Devices that don't require a separate rgb/w bit aka rgbwprotocol
-    protocols: List[
-        MinVersionProtocol
-    ]  # The device protocols, must be ordered highest version to lowest version
-    mode_to_color_mode: Dict[
-        int, Set[str]
-    ]  # A mapping of mode aka byte 2 to color mode that overrides color_modes
-    color_modes: Set[
-        str
-    ]  # The color modes to use if there is no mode_to_color_mode_mapping
-    channel_map: Dict[str, str]  # Used to remap channels
-    microphone: bool
-
-    def protocol_for_version_num(self, version_num: int) -> str:
-        protocol = self.protocols[-1].protocol
-        for min_version_protocol in self.protocols:
-            if version_num >= min_version_protocol.min_version:
-                protocol = min_version_protocol.protocol
-                break
-        return protocol
-
-
 class LEDENETChip(Enum):
     ESP8266 = auto()  # aka ESP8285
     BL602 = auto()  # supports BLE as well
@@ -107,21 +101,32 @@ class LEDENETHardware:
 
 
 BASE_MODE_MAP = {
-    0x01: {COLOR_MODE_DIM},
-    0x02: {COLOR_MODE_CCT},
-    0x03: {COLOR_MODE_RGB},
-    0x04: {COLOR_MODE_RGBW},
-    0x05: {COLOR_MODE_RGBWW},
-    0x06: COLOR_MODES_RGB_W,
-    0x07: COLOR_MODES_RGB_CCT,
+    0x01: {COLOR_MODE_DIM},  # AKA DIM
+    0x02: {COLOR_MODE_CCT},  # AKA CCT
+    0x03: {COLOR_MODE_RGB},  # AKA RGB
+    0x04: {COLOR_MODE_RGBW},  # AKA RGB&W
+    0x05: {COLOR_MODE_RGBWW},  # AKA RGB&CCT
+    0x06: COLOR_MODES_RGB_W,  # AKA RGB/W
+    0x07: COLOR_MODES_RGB_CCT,  # AKA RGB/CCT
 }
 
+
+MULTI_MODE_NUM_TO_MODE = {
+    1: COLOR_MODE_DIM,
+    2: COLOR_MODE_CCT,
+    3: COLOR_MODE_RGB,
+    4: COLOR_MODE_RGBW,
+    5: COLOR_MODE_RGBWW,
+}
+MULTI_MODE_MODE_TO_NUM = {v: k for k, v in MULTI_MODE_NUM_TO_MODE.items()}
+
 GENERIC_RGB_MAP = {
     0x13: {COLOR_MODE_RGB},  # RGB (RGB) verified on model 0x33
     0x23: {COLOR_MODE_RGB},  # RGB (GRB) verified on model 0x33
     0x33: {COLOR_MODE_RGB},  # RGB (BRG) verified on model 0x33
 }
 
+
 GENERIC_RGBW_MAP = {
     0x14: {COLOR_MODE_RGBW},  # RGB&W (RGBW) verified on model 0x06
     0x24: {COLOR_MODE_RGBW},  # RGB&W (GRBW) verified on model 0x06
@@ -164,6 +169,159 @@ GENERIC_RGBWW_MAP = {
     0xF5: {COLOR_MODE_RGBWW},  # RGB&CCT (WCBRG) verified on model 0x07
 }
 
+
+@dataclass
+class LEDENETDeviceConfigurationOptions:
+    wiring: bool  # supports changing strip order
+    num_to_wiring: Dict[int, str]
+    wiring_to_num: Dict[str, int]
+    operating_modes: bool  # has color modes ie RGB&W or RGB/W
+    num_to_operating_mode: Dict[int, str]
+    operating_mode_to_num: Dict[str, int]
+    pixels: bool
+    segments: bool
+    music_pixels: bool
+    music_segments: bool
+    ic_type: bool
+    num_to_ic_type: Dict[int, str]
+    ic_type_to_num: Dict[str, int]
+
+
+IMMUTABLE_DEVICE_CONFIG = LEDENETDeviceConfigurationOptions(  # aka fixed models
+    wiring=False,
+    num_to_wiring={},
+    wiring_to_num={},
+    operating_modes=False,
+    num_to_operating_mode={},
+    operating_mode_to_num={},
+    pixels=False,
+    segments=False,
+    music_pixels=False,
+    music_segments=False,
+    ic_type=False,
+    num_to_ic_type={},
+    ic_type_to_num={},
+)
+MULTI_MODE_DEVICE_CONFIG = LEDENETDeviceConfigurationOptions(  # aka 0x25
+    wiring=False,
+    num_to_wiring={},
+    wiring_to_num={},
+    operating_modes=True,
+    num_to_operating_mode=MULTI_MODE_NUM_TO_MODE,
+    operating_mode_to_num=MULTI_MODE_MODE_TO_NUM,
+    pixels=False,
+    segments=False,
+    music_pixels=False,
+    music_segments=False,
+    ic_type=False,
+    num_to_ic_type={},
+    ic_type_to_num={},
+)
+RGB_DEVICE_CONFIG = LEDENETDeviceConfigurationOptions(
+    wiring=True,
+    num_to_wiring=RGB_NUM_TO_WIRING,
+    wiring_to_num=RGB_WIRING_TO_NUM,
+    operating_modes=False,
+    num_to_operating_mode={},
+    operating_mode_to_num={},
+    pixels=False,
+    segments=False,
+    music_pixels=False,
+    music_segments=False,
+    ic_type=False,
+    num_to_ic_type={},
+    ic_type_to_num={},
+)
+RGBW_DEVICE_CONFIG = LEDENETDeviceConfigurationOptions(
+    wiring=True,
+    num_to_wiring=RGBW_NUM_TO_WIRING,
+    wiring_to_num=RGBW_WIRING_TO_NUM,
+    operating_modes=True,
+    num_to_operating_mode=RGBW_NUM_TO_MODE,
+    operating_mode_to_num=RGBW_MODE_TO_NUM,
+    pixels=False,
+    segments=False,
+    music_pixels=False,
+    music_segments=False,
+    ic_type=False,
+    num_to_ic_type={},
+    ic_type_to_num={},
+)
+RGBWW_DEVICE_CONFIG = LEDENETDeviceConfigurationOptions(
+    wiring=True,
+    num_to_wiring=RGBWW_NUM_TO_WIRING,
+    wiring_to_num=RGBWW_WIRING_TO_NUM,
+    operating_modes=True,
+    num_to_operating_mode=RGBWW_NUM_TO_MODE,
+    operating_mode_to_num=RGBWW_MODE_TO_NUM,
+    pixels=False,
+    segments=False,
+    music_pixels=False,
+    music_segments=False,
+    ic_type=False,
+    num_to_ic_type={},
+    ic_type_to_num={},
+)
+A1_DEVICE_CONFIG = LEDENETDeviceConfigurationOptions(
+    wiring=True,
+    num_to_wiring=ADDRESSABLE_RGB_NUM_TO_WIRING,
+    wiring_to_num=ADDRESSABLE_RGB_WIRING_TO_NUM,
+    operating_modes=False,
+    num_to_operating_mode=A1_NUM_TO_OPERATING_MODE,
+    operating_mode_to_num=A1_OPERATING_MODE_TO_NUM,
+    pixels=True,
+    segments=False,
+    music_pixels=False,
+    music_segments=False,
+    ic_type=True,
+    num_to_ic_type=A1_NUM_TO_PROTOCOL,
+    ic_type_to_num=A1_PROTOCOL_TO_NUM,
+)
+NEW_ADDRESABLE_DEVICE_CONFIG = LEDENETDeviceConfigurationOptions(
+    wiring=True,
+    num_to_wiring=ADDRESSABLE_RGB_NUM_TO_WIRING,
+    wiring_to_num=ADDRESSABLE_RGB_WIRING_TO_NUM,
+    operating_modes=False,  # can only be changed by changing protocol
+    num_to_operating_mode=NEW_ADDRESSABLE_NUM_TO_OPERATING_MODE,
+    operating_mode_to_num=NEW_ADDRESSABLE_OPERATING_MODE_TO_NUM,
+    pixels=True,
+    segments=True,
+    music_pixels=True,
+    music_segments=True,
+    ic_type=True,
+    num_to_ic_type=NEW_ADDRESSABLE_NUM_TO_PROTOCOL,
+    ic_type_to_num=NEW_ADDRESSABLE_PROTOCOL_TO_NUM,
+)
+
+
+@dataclass
+class LEDENETModel:
+    model_num: int  # The model number aka byte 1
+    models: List[str]  # The model names from discovery
+    description: str  # Description of the model ({type} {color_mode})
+    always_writes_white_and_colors: bool  # Devices that don't require a separate rgb/w bit aka rgbwprotocol
+    protocols: List[
+        MinVersionProtocol
+    ]  # The device protocols, must be ordered highest version to lowest version
+    mode_to_color_mode: Dict[
+        int, Set[str]
+    ]  # A mapping of mode aka byte 2 to color mode that overrides color_modes
+    color_modes: Set[
+        str
+    ]  # The color modes to use if there is no mode_to_color_mode_mapping
+    channel_map: Dict[str, str]  # Used to remap channels
+    microphone: bool
+    device_config: LEDENETDeviceConfigurationOptions
+
+    def protocol_for_version_num(self, version_num: int) -> str:
+        protocol = self.protocols[-1].protocol
+        for min_version_protocol in self.protocols:
+            if version_num >= min_version_protocol.min_version:
+                protocol = min_version_protocol.protocol
+                break
+        return protocol
+
+
 UNKNOWN_MODEL = "Unknown Model"
 
 # Assumed model version scheme
@@ -237,16 +395,46 @@ HARDWARE = [
         chip=LEDENETChip.BL602,
         rf_remote=True,  # verified
     ),
+    LEDENETHardware(
+        model="HF-A11",  # reported older large box controllers (may be original proto)
+        chip=LEDENETChip.HFLPB100,
+        rf_remote=False,  # unverified
+    ),
     LEDENETHardware(
         model="HF-A11-ZJ002",  # reported older large box controllers (may be original proto)
         chip=LEDENETChip.HFLPB100,
         rf_remote=False,  # unverified
     ),
+    LEDENETHardware(
+        model="HF-A11-ZJ004",  # reported older large box controllers (may be original proto)
+        chip=LEDENETChip.HFLPB100,
+        rf_remote=False,  # unverified
+    ),
+    LEDENETHardware(
+        model="HF-A11-ZJ2",  # reported older large box controllers (may be original proto)
+        chip=LEDENETChip.HFLPB100,
+        rf_remote=False,  # unverified
+    ),
+    LEDENETHardware(
+        model="HF-A11-ZJ201",  # reported older large box controllers (may be original proto)
+        chip=LEDENETChip.HFLPB100,
+        rf_remote=False,  # unverified
+    ),
+    LEDENETHardware(
+        model="HF-LPB100-ZJ2001",  # reported older large box controllers (may be original proto)
+        chip=LEDENETChip.HFLPB100,
+        rf_remote=False,  # unverified
+    ),
     LEDENETHardware(
         model="HF-LPB100",  # reported on older UFO
         chip=LEDENETChip.HFLPB100,
         rf_remote=False,  # unverified
     ),
+    LEDENETHardware(
+        model="HF-LPB100-",
+        chip=LEDENETChip.HFLPB100,
+        rf_remote=False,  # unverified
+    ),
     LEDENETHardware(
         model="HF-LPB100-0",  # reported on older UFO
         chip=LEDENETChip.HFLPB100,
@@ -257,6 +445,16 @@ HARDWARE = [
         chip=LEDENETChip.HFLPB100,
         rf_remote=False,  # unverified
     ),
+    LEDENETHardware(
+        model="HF-LPB100-ZJ001",
+        chip=LEDENETChip.HFLPB100,
+        rf_remote=False,  # unverified
+    ),
+    LEDENETHardware(
+        model="HF-LPB100-ZJ011",
+        chip=LEDENETChip.HFLPB100,
+        rf_remote=False,  # unverified
+    ),
     LEDENETHardware(
         model="HF-LPB100-ZJ002",  # seen on older UFO
         chip=LEDENETChip.HFLPB100,
@@ -280,6 +478,36 @@ MODELS = [
         color_modes={COLOR_MODE_RGB},
         channel_map={},
         microphone=False,
+        device_config=IMMUTABLE_DEVICE_CONFIG,
+    ),
+    LEDENETModel(
+        model_num=0x02,
+        models=[],
+        description="Legacy Controller Dimmable",
+        always_writes_white_and_colors=False,  # Formerly rgbwprotocol
+        protocols=[MinVersionProtocol(0, PROTOCOL_LEDENET_ORIGINAL)],
+        mode_to_color_mode={},  # Only mode should be 0x02
+        color_modes={COLOR_MODE_DIM},  # Formerly rgbwcapable
+        channel_map={STATE_WARM_WHITE: STATE_RED, STATE_RED: STATE_WARM_WHITE},
+        microphone=False,
+        device_config=IMMUTABLE_DEVICE_CONFIG,
+    ),
+    LEDENETModel(
+        model_num=0x03,
+        models=["HF-A11-ZJ002"],
+        description="Legacy Controller CCT",
+        always_writes_white_and_colors=False,  # Formerly rgbwprotocol
+        protocols=[MinVersionProtocol(0, PROTOCOL_LEDENET_ORIGINAL_CCT)],
+        mode_to_color_mode={},
+        color_modes={COLOR_MODE_CCT},  # Formerly rgbwcapable
+        channel_map={
+            STATE_WARM_WHITE: STATE_RED,
+            STATE_RED: STATE_WARM_WHITE,
+            STATE_COOL_WHITE: STATE_GREEN,
+            STATE_GREEN: STATE_COOL_WHITE,
+        },
+        microphone=False,
+        device_config=IMMUTABLE_DEVICE_CONFIG,
     ),
     LEDENETModel(
         model_num=0x04,
@@ -297,6 +525,7 @@ MODELS = [
         color_modes={COLOR_MODE_RGBW},  # Formerly rgbwcapable
         channel_map={},
         microphone=False,
+        device_config=IMMUTABLE_DEVICE_CONFIG,
     ),
     LEDENETModel(
         model_num=0x06,
@@ -320,6 +549,7 @@ MODELS = [
         color_modes={COLOR_MODE_RGBW},  # Formerly rgbwcapable
         channel_map={},
         microphone=False,
+        device_config=RGBW_DEVICE_CONFIG,
     ),
     LEDENETModel(
         model_num=0x07,
@@ -335,6 +565,7 @@ MODELS = [
         color_modes={COLOR_MODE_RGBWW},  # Formerly rgbwcapable
         channel_map={},
         microphone=False,
+        device_config=RGBWW_DEVICE_CONFIG,
     ),
     LEDENETModel(
         model_num=0x08,
@@ -351,6 +582,7 @@ MODELS = [
         color_modes={COLOR_MODE_RGB},
         channel_map={},
         microphone=True,
+        device_config=RGB_DEVICE_CONFIG,
     ),
     LEDENETModel(
         model_num=0x09,  # same as 0xE1
@@ -367,6 +599,7 @@ MODELS = [
             STATE_GREEN: STATE_COOL_WHITE,
         },
         microphone=False,
+        device_config=IMMUTABLE_DEVICE_CONFIG,
     ),
     LEDENETModel(
         model_num=0x0B,
@@ -378,6 +611,7 @@ MODELS = [
         color_modes=set(),  # no color modes
         channel_map={},
         microphone=False,
+        device_config=IMMUTABLE_DEVICE_CONFIG,
     ),
     LEDENETModel(
         # 'AK001-ZJ2104' likely supports turning on by effect/levels set
@@ -394,6 +628,7 @@ MODELS = [
         color_modes=COLOR_MODES_RGB_CCT,
         channel_map={},
         microphone=False,
+        device_config=IMMUTABLE_DEVICE_CONFIG,
     ),
     LEDENETModel(
         model_num=0x10,
@@ -405,6 +640,7 @@ MODELS = [
         color_modes=COLOR_MODES_ADDRESSABLE,
         channel_map={},
         microphone=False,
+        device_config=IMMUTABLE_DEVICE_CONFIG,
     ),
     LEDENETModel(
         model_num=0x1A,
@@ -416,6 +652,7 @@ MODELS = [
         color_modes=COLOR_MODES_ADDRESSABLE,
         channel_map={},
         microphone=False,
+        device_config=IMMUTABLE_DEVICE_CONFIG,
     ),
     LEDENETModel(
         model_num=0x16,
@@ -432,6 +669,7 @@ MODELS = [
             STATE_GREEN: STATE_COOL_WHITE,
         },
         microphone=False,
+        device_config=IMMUTABLE_DEVICE_CONFIG,
     ),
     LEDENETModel(
         model_num=0x17,
@@ -443,6 +681,7 @@ MODELS = [
         color_modes={COLOR_MODE_DIM},  # Formerly rgbwcapable
         channel_map={STATE_WARM_WHITE: STATE_RED, STATE_RED: STATE_WARM_WHITE},
         microphone=False,
+        device_config=IMMUTABLE_DEVICE_CONFIG,
     ),
     LEDENETModel(
         model_num=0x18,
@@ -454,6 +693,7 @@ MODELS = [
         color_modes=set(),  # no color modes -- UNVERIFIED
         channel_map={},
         microphone=False,
+        device_config=IMMUTABLE_DEVICE_CONFIG,
     ),
     LEDENETModel(
         model_num=0x1B,
@@ -465,6 +705,7 @@ MODELS = [
         color_modes={COLOR_MODE_RGB},
         channel_map={},
         microphone=False,
+        device_config=IMMUTABLE_DEVICE_CONFIG,
     ),
     LEDENETModel(
         model_num=0x19,
@@ -476,6 +717,7 @@ MODELS = [
         color_modes=set(),  # no color modes
         channel_map={},
         microphone=False,
+        device_config=IMMUTABLE_DEVICE_CONFIG,
     ),
     LEDENETModel(
         model_num=0x1C,
@@ -488,6 +730,7 @@ MODELS = [
         color_modes={COLOR_MODE_CCT},  # Formerly rgbwcapable
         channel_map={},
         microphone=False,
+        device_config=IMMUTABLE_DEVICE_CONFIG,
     ),
     LEDENETModel(
         model_num=0x21,
@@ -505,6 +748,7 @@ MODELS = [
         color_modes={COLOR_MODE_DIM},  # Formerly rgbwcapable
         channel_map={STATE_WARM_WHITE: STATE_RED, STATE_RED: STATE_WARM_WHITE},
         microphone=False,
+        device_config=IMMUTABLE_DEVICE_CONFIG,
     ),
     LEDENETModel(
         model_num=0x25,
@@ -517,6 +761,7 @@ MODELS = [
         color_modes={COLOR_MODE_RGBWW},  # Formerly rgbwcapable
         channel_map={},
         microphone=False,
+        device_config=MULTI_MODE_DEVICE_CONFIG,
     ),
     LEDENETModel(
         model_num=0x33,
@@ -545,6 +790,7 @@ MODELS = [
         color_modes={COLOR_MODE_RGB},
         channel_map={},
         microphone=False,
+        device_config=RGB_DEVICE_CONFIG,
     ),
     LEDENETModel(
         model_num=0x35,
@@ -571,6 +817,7 @@ MODELS = [
         color_modes=COLOR_MODES_RGB_CCT,
         channel_map={},
         microphone=False,
+        device_config=IMMUTABLE_DEVICE_CONFIG,
     ),
     LEDENETModel(
         model_num=0x41,
@@ -587,10 +834,13 @@ MODELS = [
         color_modes={COLOR_MODE_DIM},  # Formerly rgbwcapable
         channel_map={STATE_WARM_WHITE: STATE_RED, STATE_RED: STATE_WARM_WHITE},
         microphone=False,
+        device_config=IMMUTABLE_DEVICE_CONFIG,
     ),
     LEDENETModel(
         model_num=0x44,
-        models=["AK001-ZJ200"],
+        # v8 - AK001-ZJ200 aka old flux
+        # v9 - AK001-ZJ210
+        models=["AK001-ZJ200", "AK001-ZJ210"],
         description="Bulb RGBW",
         always_writes_white_and_colors=False,  # Formerly rgbwprotocol
         protocols=[MinVersionProtocol(0, PROTOCOL_LEDENET_8BYTE)],
@@ -598,6 +848,7 @@ MODELS = [
         color_modes=COLOR_MODES_RGB_W,  # Formerly rgbwcapable
         channel_map={},
         microphone=False,
+        device_config=IMMUTABLE_DEVICE_CONFIG,
     ),
     LEDENETModel(
         model_num=0x45,
@@ -609,6 +860,7 @@ MODELS = [
         color_modes={COLOR_MODE_RGB, COLOR_MODE_DIM},  # Formerly rgbwcapable
         channel_map={},
         microphone=False,
+        device_config=IMMUTABLE_DEVICE_CONFIG,
     ),
     LEDENETModel(
         model_num=0x52,
@@ -625,6 +877,7 @@ MODELS = [
             STATE_GREEN: STATE_COOL_WHITE,
         },
         microphone=False,
+        device_config=IMMUTABLE_DEVICE_CONFIG,
     ),
     LEDENETModel(
         model_num=0x54,
@@ -636,6 +889,7 @@ MODELS = [
         color_modes=COLOR_MODES_RGB_W,  # Formerly rgbwcapable
         channel_map={},
         microphone=False,
+        device_config=IMMUTABLE_DEVICE_CONFIG,
     ),
     LEDENETModel(
         model_num=0x62,
@@ -652,6 +906,7 @@ MODELS = [
             STATE_GREEN: STATE_COOL_WHITE,
         },
         microphone=False,
+        device_config=IMMUTABLE_DEVICE_CONFIG,
     ),
     LEDENETModel(
         model_num=0x81,
@@ -663,6 +918,7 @@ MODELS = [
         color_modes={COLOR_MODE_RGBW},  # Formerly rgbwcapable
         channel_map={},
         microphone=False,
+        device_config=IMMUTABLE_DEVICE_CONFIG,
     ),
     LEDENETModel(
         model_num=0x93,
@@ -675,6 +931,7 @@ MODELS = [
         color_modes=set(),  # no color modes
         channel_map={},
         microphone=False,
+        device_config=IMMUTABLE_DEVICE_CONFIG,
     ),
     LEDENETModel(
         model_num=0x94,
@@ -686,6 +943,7 @@ MODELS = [
         color_modes=set(),  # no color modes
         channel_map={},
         microphone=False,
+        device_config=IMMUTABLE_DEVICE_CONFIG,
     ),
     LEDENETModel(
         model_num=0x95,
@@ -697,6 +955,7 @@ MODELS = [
         color_modes=set(),  # no color modes
         channel_map={},
         microphone=False,
+        device_config=IMMUTABLE_DEVICE_CONFIG,
     ),
     LEDENETModel(
         model_num=0x96,
@@ -708,6 +967,7 @@ MODELS = [
         color_modes=set(),  # no color modes
         channel_map={},
         microphone=False,
+        device_config=IMMUTABLE_DEVICE_CONFIG,
     ),
     LEDENETModel(
         model_num=0x97,  # 0x97
@@ -720,6 +980,7 @@ MODELS = [
         color_modes=set(),  # no color modes
         channel_map={},
         microphone=False,
+        device_config=IMMUTABLE_DEVICE_CONFIG,
     ),
     LEDENETModel(
         model_num=0xA1,
@@ -731,6 +992,7 @@ MODELS = [
         color_modes=COLOR_MODES_ADDRESSABLE,
         channel_map={},
         microphone=False,
+        device_config=A1_DEVICE_CONFIG,
     ),
     LEDENETModel(
         model_num=0xA2,
@@ -743,6 +1005,7 @@ MODELS = [
         color_modes=COLOR_MODES_ADDRESSABLE,
         channel_map={},
         microphone=True,
+        device_config=NEW_ADDRESABLE_DEVICE_CONFIG,
     ),
     LEDENETModel(
         model_num=0xA3,
@@ -756,6 +1019,7 @@ MODELS = [
         color_modes=COLOR_MODES_ADDRESSABLE,
         channel_map={},
         microphone=True,
+        device_config=NEW_ADDRESABLE_DEVICE_CONFIG,
     ),
     LEDENETModel(
         model_num=0xA4,
@@ -769,6 +1033,7 @@ MODELS = [
         color_modes=COLOR_MODES_ADDRESSABLE,
         channel_map={},
         microphone=True,
+        device_config=NEW_ADDRESABLE_DEVICE_CONFIG,
     ),
     LEDENETModel(
         model_num=0xD1,
@@ -780,6 +1045,7 @@ MODELS = [
         color_modes=set(),  # no color modes -- UNVERIFIED
         channel_map={},
         microphone=False,
+        device_config=IMMUTABLE_DEVICE_CONFIG,
     ),
     LEDENETModel(
         model_num=0xE1,
@@ -796,6 +1062,7 @@ MODELS = [
             STATE_GREEN: STATE_COOL_WHITE,
         },
         microphone=False,
+        device_config=IMMUTABLE_DEVICE_CONFIG,
     ),
     LEDENETModel(
         model_num=0xE2,
@@ -807,6 +1074,7 @@ MODELS = [
         color_modes=set(),  # no color modes -- UNVERIFIED
         channel_map={},
         microphone=False,
+        device_config=IMMUTABLE_DEVICE_CONFIG,
     ),
 ]
 
@@ -838,6 +1106,7 @@ def _unknown_ledenet_model(model_num: int, fallback_protocol: str) -> LEDENETMod
         color_modes={COLOR_MODE_RGB},
         channel_map={},
         microphone=False,
+        device_config=IMMUTABLE_DEVICE_CONFIG,
     )
 
 
